==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/annotated_dup.js <==
var annotated_dup =
[
    [ "Steinberg", "namespaceSteinberg.html", [
      [ "FUnknownImpl", "namespaceSteinberg_1_1FUnknownImpl.html", [
        [ "Detail", "namespaceSteinberg_1_1FUnknownImpl_1_1Detail.html", [
          [ "NonDestroyable", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable" ],
          [ "QueryInterfaceEnd", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd" ],
          [ "RefCounted", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted" ]
        ] ],
        [ "Destroyer", "structSteinberg_1_1FUnknownImpl_1_1Destroyer.html", null ],
        [ "Directly", "structSteinberg_1_1FUnknownImpl_1_1Directly.html", null ],
        [ "HideIIDBase", "structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html", "structSteinberg_1_1FUnknownImpl_1_1HideIIDBase" ],
        [ "ImplementsImpl", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl.html", null ],
        [ "ImplementsImpl< Base, Indirectly< IndirectInterfaces... >, Directly< DirectInterfaces... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01Base_00_01Indirectly_3_01IndirectInterfaces9a4a5325b3bc049eba78ef3421c75dc0.html", null ],
        [ "ImplementsImpl< BaseClass, Directly< I, DirectIFs... >, Indirectly< IndirectIFs... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987" ],
        [ "Indirectly", "structSteinberg_1_1FUnknownImpl_1_1Indirectly.html", null ],
        [ "UID", "structSteinberg_1_1FUnknownImpl_1_1UID.html", "structSteinberg_1_1FUnknownImpl_1_1UID" ]
      ] ],
      [ "Linux", "namespaceSteinberg_1_1Linux.html", [
        [ "IEventHandler", "classSteinberg_1_1Linux_1_1IEventHandler.html", "classSteinberg_1_1Linux_1_1IEventHandler" ],
        [ "IRunLoop", "classSteinberg_1_1Linux_1_1IRunLoop.html", "classSteinberg_1_1Linux_1_1IRunLoop" ],
        [ "ITimerHandler", "classSteinberg_1_1Linux_1_1ITimerHandler.html", "classSteinberg_1_1Linux_1_1ITimerHandler" ]
      ] ],
      [ "ConstStringTable", "classSteinberg_1_1ConstStringTable.html", "classSteinberg_1_1ConstStringTable" ],
      [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
      [ "FUID", "classSteinberg_1_1FUID.html", "classSteinberg_1_1FUID" ],
      [ "FUnknown", "classSteinberg_1_1FUnknown.html", "classSteinberg_1_1FUnknown" ],
      [ "FUnknownPtr", "classSteinberg_1_1FUnknownPtr.html", "classSteinberg_1_1FUnknownPtr" ],
      [ "FVariant", "classSteinberg_1_1FVariant.html", "classSteinberg_1_1FVariant" ],
      [ "IAttributes", "classSteinberg_1_1IAttributes.html", "classSteinberg_1_1IAttributes" ],
      [ "IAttributes2", "classSteinberg_1_1IAttributes2.html", "classSteinberg_1_1IAttributes2" ],
      [ "IBStream", "classSteinberg_1_1IBStream.html", "classSteinberg_1_1IBStream" ],
      [ "ICloneable", "classSteinberg_1_1ICloneable.html", "classSteinberg_1_1ICloneable" ],
      [ "IDependent", "classSteinberg_1_1IDependent.html", "classSteinberg_1_1IDependent" ],
      [ "IErrorContext", "classSteinberg_1_1IErrorContext.html", "classSteinberg_1_1IErrorContext" ],
      [ "IPersistent", "classSteinberg_1_1IPersistent.html", "classSteinberg_1_1IPersistent" ],
      [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", "classSteinberg_1_1IPlugFrame" ],
      [ "IPluginBase", "classSteinberg_1_1IPluginBase.html", "classSteinberg_1_1IPluginBase" ],
      [ "IPluginCompatibility", "classSteinberg_1_1IPluginCompatibility.html", "classSteinberg_1_1IPluginCompatibility" ],
      [ "IPluginFactory", "classSteinberg_1_1IPluginFactory.html", "classSteinberg_1_1IPluginFactory" ],
      [ "IPluginFactory2", "classSteinberg_1_1IPluginFactory2.html", "classSteinberg_1_1IPluginFactory2" ],
      [ "IPluginFactory3", "classSteinberg_1_1IPluginFactory3.html", "classSteinberg_1_1IPluginFactory3" ],
      [ "IPlugView", "classSteinberg_1_1IPlugView.html", "classSteinberg_1_1IPlugView" ],
      [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", "classSteinberg_1_1IPlugViewContentScaleSupport" ],
      [ "IPtr", "classSteinberg_1_1IPtr.html", "classSteinberg_1_1IPtr" ],
      [ "ISizeableStream", "classSteinberg_1_1ISizeableStream.html", "classSteinberg_1_1ISizeableStream" ],
      [ "IString", "classSteinberg_1_1IString.html", "classSteinberg_1_1IString" ],
      [ "IStringResult", "classSteinberg_1_1IStringResult.html", "classSteinberg_1_1IStringResult" ],
      [ "IUpdateHandler", "classSteinberg_1_1IUpdateHandler.html", "classSteinberg_1_1IUpdateHandler" ],
      [ "KeyCode", "structSteinberg_1_1KeyCode.html", "structSteinberg_1_1KeyCode" ],
      [ "OPtr", "classSteinberg_1_1OPtr.html", "classSteinberg_1_1OPtr" ],
      [ "PClassInfo", "structSteinberg_1_1PClassInfo.html", "structSteinberg_1_1PClassInfo" ],
      [ "PClassInfo2", "structSteinberg_1_1PClassInfo2.html", "structSteinberg_1_1PClassInfo2" ],
      [ "PClassInfoW", "structSteinberg_1_1PClassInfoW.html", "structSteinberg_1_1PClassInfoW" ],
      [ "PFactoryInfo", "structSteinberg_1_1PFactoryInfo.html", "structSteinberg_1_1PFactoryInfo" ],
      [ "UString", "classSteinberg_1_1UString.html", "classSteinberg_1_1UString" ],
      [ "UStringBuffer", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
      [ "ViewRect", "structSteinberg_1_1ViewRect.html", "structSteinberg_1_1ViewRect" ]
    ] ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/annotated_dup.js <==
var annotated_dup =
[
    [ "Steinberg", "namespaceSteinberg.html", [
      [ "FUnknownImpl", "namespaceSteinberg_1_1FUnknownImpl.html", [
        [ "Detail", "namespaceSteinberg_1_1FUnknownImpl_1_1Detail.html", [
          [ "NonDestroyable", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable" ],
          [ "QueryInterfaceEnd", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd" ],
          [ "RefCounted", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted.html", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted" ]
        ] ],
        [ "Destroyer", "structSteinberg_1_1FUnknownImpl_1_1Destroyer.html", null ],
        [ "Directly", "structSteinberg_1_1FUnknownImpl_1_1Directly.html", null ],
        [ "HideIIDBase", "structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html", "structSteinberg_1_1FUnknownImpl_1_1HideIIDBase" ],
        [ "ImplementsImpl", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl.html", null ],
        [ "ImplementsImpl< Base, Indirectly< IndirectInterfaces... >, Directly< DirectInterfaces... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01Base_00_01Indirectly_3_01IndirectInterfaces9a4a5325b3bc049eba78ef3421c75dc0.html", null ],
        [ "Indirectly", "structSteinberg_1_1FUnknownImpl_1_1Indirectly.html", null ],
        [ "UID", "structSteinberg_1_1FUnknownImpl_1_1UID.html", "structSteinberg_1_1FUnknownImpl_1_1UID" ]
      ] ],
      [ "Linux", "namespaceSteinberg_1_1Linux.html", [
        [ "IEventHandler", "classSteinberg_1_1Linux_1_1IEventHandler.html", "classSteinberg_1_1Linux_1_1IEventHandler" ],
        [ "IRunLoop", "classSteinberg_1_1Linux_1_1IRunLoop.html", "classSteinberg_1_1Linux_1_1IRunLoop" ],
        [ "ITimerHandler", "classSteinberg_1_1Linux_1_1ITimerHandler.html", "classSteinberg_1_1Linux_1_1ITimerHandler" ]
      ] ],
      [ "U", "namespaceSteinberg_1_1U.html", [
        [ "Directly", "structSteinberg_1_1U_1_1Directly.html", null ],
        [ "Indirectly", "structSteinberg_1_1U_1_1Indirectly.html", null ],
        [ "UID", "structSteinberg_1_1U_1_1UID.html", "structSteinberg_1_1U_1_1UID" ]
      ] ],
      [ "ConstStringTable", "classSteinberg_1_1ConstStringTable.html", "classSteinberg_1_1ConstStringTable" ],
      [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
      [ "FUID", "classSteinberg_1_1FUID.html", "classSteinberg_1_1FUID" ],
      [ "FUnknown", "classSteinberg_1_1FUnknown.html", "classSteinberg_1_1FUnknown" ],
      [ "FUnknownPtr", "classSteinberg_1_1FUnknownPtr.html", "classSteinberg_1_1FUnknownPtr" ],
      [ "FVariant", "classSteinberg_1_1FVariant.html", "classSteinberg_1_1FVariant" ],
      [ "IAttributes", "classSteinberg_1_1IAttributes.html", "classSteinberg_1_1IAttributes" ],
      [ "IAttributes2", "classSteinberg_1_1IAttributes2.html", "classSteinberg_1_1IAttributes2" ],
      [ "IBStream", "classSteinberg_1_1IBStream.html", "classSteinberg_1_1IBStream" ],
      [ "ICloneable", "classSteinberg_1_1ICloneable.html", "classSteinberg_1_1ICloneable" ],
      [ "IDependent", "classSteinberg_1_1IDependent.html", "classSteinberg_1_1IDependent" ],
      [ "IErrorContext", "classSteinberg_1_1IErrorContext.html", "classSteinberg_1_1IErrorContext" ],
      [ "IPersistent", "classSteinberg_1_1IPersistent.html", "classSteinberg_1_1IPersistent" ],
      [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", "classSteinberg_1_1IPlugFrame" ],
      [ "IPluginBase", "classSteinberg_1_1IPluginBase.html", "classSteinberg_1_1IPluginBase" ],
      [ "IPluginCompatibility", "classSteinberg_1_1IPluginCompatibility.html", "classSteinberg_1_1IPluginCompatibility" ],
      [ "IPluginFactory", "classSteinberg_1_1IPluginFactory.html", "classSteinberg_1_1IPluginFactory" ],
      [ "IPluginFactory2", "classSteinberg_1_1IPluginFactory2.html", "classSteinberg_1_1IPluginFactory2" ],
      [ "IPluginFactory3", "classSteinberg_1_1IPluginFactory3.html", "classSteinberg_1_1IPluginFactory3" ],
      [ "IPlugView", "classSteinberg_1_1IPlugView.html", "classSteinberg_1_1IPlugView" ],
      [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", "classSteinberg_1_1IPlugViewContentScaleSupport" ],
      [ "IPtr", "classSteinberg_1_1IPtr.html", "classSteinberg_1_1IPtr" ],
      [ "ISizeableStream", "classSteinberg_1_1ISizeableStream.html", "classSteinberg_1_1ISizeableStream" ],
      [ "IString", "classSteinberg_1_1IString.html", "classSteinberg_1_1IString" ],
      [ "IStringResult", "classSteinberg_1_1IStringResult.html", "classSteinberg_1_1IStringResult" ],
      [ "IUpdateHandler", "classSteinberg_1_1IUpdateHandler.html", "classSteinberg_1_1IUpdateHandler" ],
      [ "KeyCode", "structSteinberg_1_1KeyCode.html", "structSteinberg_1_1KeyCode" ],
      [ "OPtr", "classSteinberg_1_1OPtr.html", "classSteinberg_1_1OPtr" ],
      [ "PClassInfo", "structSteinberg_1_1PClassInfo.html", "structSteinberg_1_1PClassInfo" ],
      [ "PClassInfo2", "structSteinberg_1_1PClassInfo2.html", "structSteinberg_1_1PClassInfo2" ],
      [ "PClassInfoW", "structSteinberg_1_1PClassInfoW.html", "structSteinberg_1_1PClassInfoW" ],
      [ "PFactoryInfo", "structSteinberg_1_1PFactoryInfo.html", "structSteinberg_1_1PFactoryInfo" ],
      [ "UString", "classSteinberg_1_1UString.html", "classSteinberg_1_1UString" ],
      [ "UStringBuffer", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
      [ "ViewRect", "structSteinberg_1_1ViewRect.html", "structSteinberg_1_1ViewRect" ]
    ] ]
];
